window.Gleam.initSearch([{"doc":"gleam_retry","title":"gleam_retry","content":"# retry\n\n[![Package Version](https://img.shields.io/hexpm/v/retry)](https://hex.pm/packages/gleam_retry)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gleam_retry/)\n\nRetry code that can fail.\n\n## Usage\n\n```sh\ngleam add retry@1\n```\n\n```gleam\nimport gleam/int\nimport gleam/retry\n\npub type NetworkError {\n  ServerDown\n  Timeout(Int)\n  InvalidStatusCode(Int)\n  InvalidResponseBody(String)\n}\n\npub fn main() {\n  retry.new(max_attempts: 5, wait_time: 100)\n  // Optional configuration\n  |&gt; retry.allow(allow: fn(error) {\n    case error {\n      InvalidStatusCode(code) if code &gt;= 500 &amp;&amp; code &lt; 600 -&gt; True\n      Timeout(_) -&gt; True\n      _ -&gt; False\n    }\n  })\n  // Optional configuration\n  |&gt; retry.backoff(next_wait_time: int.multiply(_, 2))\n  |&gt; retry.execute(operation: fn() {\n    case int.random(4) {\n      0 -&gt; Error(ServerDown)\n      1 -&gt; Error(Timeout(5000))\n      2 -&gt; Error(InvalidStatusCode(503))\n      3 -&gt; Error(InvalidResponseBody(&quot;Malformed JSON&quot;))\n      _ -&gt; Ok(&quot;Success!&quot;)\n    }\n  })\n}\n```\n\n## Targets\n\n`retry` supports the Erlang target.\n","url":"index.html"},{"doc":"gleam/retry","title":"Config","content":"pub opaque type Config(a, b)\n\n\nSynonyms:\ngleam/retry.Config\ngleam/retry Config","url":"gleam/retry.html#Config"},{"doc":"gleam/retry","title":"RetryError","content":"pub type RetryError(a) {\n  RetriesExhausted(errors: List(a))\n  UnallowedError(error: a)\n}\n Represents errors that can occur during a retry attempts.\nRetriesExhausted(errors: List(a))\n Indicates that all retry attempts have been exhausted. Contains an ordered\n list of all errors encountered during the execution attempts.\n\nUnallowedError(error: a)\n Indicates that `retry` ran into an error that wasn&#39;t allowed. Contains the\n specific error that caused the retry to stop. By default, all errors are\n allowed. Use the `allow()` function to specify which errors should trigger\n a retry.\n\nSynonyms:\ngleam/retry.RetryError\ngleam/retry RetryError","url":"gleam/retry.html#RetryError"},{"doc":"gleam/retry","title":"allow","content":"pub fn allow(\n  config: Config(a, b),\n  allow allow: fn(b) -&gt; Bool,\n) -&gt; Config(a, b)\n Sets the logic for determining whether an error should trigger a retry.\n Expects a function that takes an error and returns a boolean. Use this\n function to match on your error types and return `True` for errors that\n should trigger a retry, and `False` for errors that should not.\nSynonyms:\ngleam/retry.allow\ngleam/retry allow","url":"gleam/retry.html#allow"},{"doc":"gleam/retry","title":"backoff","content":"pub fn backoff(\n  config: Config(a, b),\n  next_wait_time next_wait_time: fn(Int) -&gt; Int,\n) -&gt; Config(a, b)\n Sets the backoff strategy for increasing wait times between retry attempts.\n Expects a function that takes the previous wait time and returns a the next\n wait time.\nSynonyms:\ngleam/retry.backoff\ngleam/retry backoff","url":"gleam/retry.html#backoff"},{"doc":"gleam/retry","title":"execute","content":"pub fn execute(\n  config: Config(a, b),\n  operation operation: fn() -&gt; Result(a, b),\n) -&gt; Result(a, RetryError(b))\n Initiates the retry operation with the provided configuration and operation.\n\n Returns `Ok(a)` if the operation succeeds, or `Error(RetryError(b))`.\nSynonyms:\ngleam/retry.execute\ngleam/retry execute","url":"gleam/retry.html#execute"},{"doc":"gleam/retry","title":"new","content":"pub fn new(\n  max_attempts max_attempts: Int,\n  wait_time wait_time: Int,\n) -&gt; Config(a, b)\n Creates a new configuration with the specified `max_attempts` and\n `wait_time`.\n\n Configuration defaults:\n - `next_wait_time`: constant\n - `allow`: all errors\nSynonyms:\ngleam/retry.new\ngleam/retry new","url":"gleam/retry.html#new"},{"doc":"gleam/retry","title":"gleam/retry","content":" `retry` executes a fallible operation multiple times. Various aspects can\n be configured: the number of retry attempts, the duration between attempts,\n the strategy for adjusting wait times, and the types of errors that should\n trigger a retry.","url":"gleam/retry.html"}]);